from collections import OrderedDict
from rest_framework.response import Response
from rest_framework.pagination import PageNumberPagination


class ReactAdminPagination(PageNumberPagination):
    page_query_param = "page"
    page_size_query_param = "perPage"

    def get_paginated_response(self, data):
        count = self.page.paginator.count
        item_starting_index = self.page.start_index() - 1
        item_ending_index = self.page.end_index() - 1

        content_range = "items {0}-{1}/{2}".format(
            item_starting_index, item_ending_index, count
        )

        # headers = {"Content-Range": content_range}
        headers = {"x-total-count": count}

        return Response(
            OrderedDict(
                [
                    ("x-total-count", count),
                    ("next", self.get_next_link()),
                    ("previous", self.get_previous_link()),
                    ("results", data),
                ]
            ),
            headers=headers,
        )


class PageNumberWithPageSizePagination(PageNumberPagination):
    page_size_query_param = "page_size"
